@@ -16,7 +16,7 @@ Usage::
     session_client: CostExplorerClient = session.client("ce")
     ```
 """
-from mypy_boto3_ce.client import CostExplorerClient
+from .client import CostExplorerClient
 
 Client = CostExplorerClient
 
