@@ -30,6 +30,7 @@ __all__ = (
     "CostCategoryStatusComponentType",
     "CostCategoryStatusType",
     "DimensionType",
+    "FindingReasonCodeType",
     "GranularityType",
     "GroupDefinitionTypeType",
     "LookbackPeriodInDaysType",
@@ -40,6 +41,7 @@ __all__ = (
     "NumericOperatorType",
     "OfferingClassType",
     "PaymentOptionType",
+    "PlatformDifferenceType",
     "RecommendationTargetType",
     "RightsizingTypeType",
     "SavingsPlansDataTypeType",
@@ -93,6 +95,24 @@ DimensionType = Literal[
     "USAGE_TYPE",
     "USAGE_TYPE_GROUP",
 ]
+FindingReasonCodeType = Literal[
+    "CPU_OVER_PROVISIONED",
+    "CPU_UNDER_PROVISIONED",
+    "DISK_IOPS_OVER_PROVISIONED",
+    "DISK_IOPS_UNDER_PROVISIONED",
+    "DISK_THROUGHPUT_OVER_PROVISIONED",
+    "DISK_THROUGHPUT_UNDER_PROVISIONED",
+    "EBS_IOPS_OVER_PROVISIONED",
+    "EBS_IOPS_UNDER_PROVISIONED",
+    "EBS_THROUGHPUT_OVER_PROVISIONED",
+    "EBS_THROUGHPUT_UNDER_PROVISIONED",
+    "MEMORY_OVER_PROVISIONED",
+    "MEMORY_UNDER_PROVISIONED",
+    "NETWORK_BANDWIDTH_OVER_PROVISIONED",
+    "NETWORK_BANDWIDTH_UNDER_PROVISIONED",
+    "NETWORK_PPS_OVER_PROVISIONED",
+    "NETWORK_PPS_UNDER_PROVISIONED",
+]
 GranularityType = Literal["DAILY", "HOURLY", "MONTHLY"]
 GroupDefinitionTypeType = Literal["COST_CATEGORY", "DIMENSION", "TAG"]
 LookbackPeriodInDaysType = Literal["SEVEN_DAYS", "SIXTY_DAYS", "THIRTY_DAYS"]
@@ -122,6 +142,13 @@ PaymentOptionType = Literal[
     "NO_UPFRONT",
     "PARTIAL_UPFRONT",
 ]
+PlatformDifferenceType = Literal[
+    "HYPERVISOR",
+    "INSTANCE_STORE_AVAILABILITY",
+    "NETWORK_INTERFACE",
+    "STORAGE_INTERFACE",
+    "VIRTUALIZATION_TYPE",
+]
 RecommendationTargetType = Literal["CROSS_INSTANCE_FAMILY", "SAME_INSTANCE_FAMILY"]
 RightsizingTypeType = Literal["MODIFY", "TERMINATE"]
 SavingsPlansDataTypeType = Literal["AMORTIZED_COMMITMENT", "ATTRIBUTES", "SAVINGS", "UTILIZATION"]
