@@ -22,6 +22,7 @@ from .literals import (
     CostCategoryRuleTypeType,
     CostCategoryStatusType,
     DimensionType,
+    FindingReasonCodeType,
     GroupDefinitionTypeType,
     LookbackPeriodInDaysType,
     MatchOptionType,
@@ -29,6 +30,7 @@ from .literals import (
     NumericOperatorType,
     OfferingClassType,
     PaymentOptionType,
+    PlatformDifferenceType,
     RecommendationTargetType,
     RightsizingTypeType,
     SortOrderType,
@@ -74,6 +76,7 @@ __all__ = (
     "DescribeCostCategoryDefinitionResponseTypeDef",
     "DimensionValuesTypeDef",
     "DimensionValuesWithAttributesTypeDef",
+    "DiskResourceUtilizationTypeDef",
     "EBSResourceUtilizationTypeDef",
     "EC2InstanceDetailsTypeDef",
     "EC2ResourceDetailsTypeDef",
@@ -108,6 +111,7 @@ __all__ = (
     "ListCostCategoryDefinitionsResponseTypeDef",
     "MetricValueTypeDef",
     "ModifyRecommendationDetailTypeDef",
+    "NetworkResourceUtilizationTypeDef",
     "ProvideAnomalyFeedbackResponseTypeDef",
     "RDSInstanceDetailsTypeDef",
     "RedshiftInstanceDetailsTypeDef",
@@ -473,6 +477,17 @@ DimensionValuesWithAttributesTypeDef = TypedDict(
     total=False,
 )
 
+DiskResourceUtilizationTypeDef = TypedDict(
+    "DiskResourceUtilizationTypeDef",
+    {
+        "DiskReadOpsPerSecond": str,
+        "DiskWriteOpsPerSecond": str,
+        "DiskReadBytesPerSecond": str,
+        "DiskWriteBytesPerSecond": str,
+    },
+    total=False,
+)
+
 EBSResourceUtilizationTypeDef = TypedDict(
     "EBSResourceUtilizationTypeDef",
     {
@@ -522,6 +537,8 @@ EC2ResourceUtilizationTypeDef = TypedDict(
         "MaxMemoryUtilizationPercentage": str,
         "MaxStorageUtilizationPercentage": str,
         "EBSResourceUtilization": "EBSResourceUtilizationTypeDef",
+        "DiskResourceUtilization": "DiskResourceUtilizationTypeDef",
+        "NetworkResourceUtilization": "NetworkResourceUtilizationTypeDef",
     },
     total=False,
 )
@@ -973,6 +990,17 @@ ModifyRecommendationDetailTypeDef = TypedDict(
     total=False,
 )
 
+NetworkResourceUtilizationTypeDef = TypedDict(
+    "NetworkResourceUtilizationTypeDef",
+    {
+        "NetworkInBytesPerSecond": str,
+        "NetworkOutBytesPerSecond": str,
+        "NetworkPacketsInPerSecond": str,
+        "NetworkPacketsOutPerSecond": str,
+    },
+    total=False,
+)
+
 ProvideAnomalyFeedbackResponseTypeDef = TypedDict(
     "ProvideAnomalyFeedbackResponseTypeDef",
     {
@@ -1176,6 +1204,7 @@ RightsizingRecommendationTypeDef = TypedDict(
         "RightsizingType": RightsizingTypeType,
         "ModifyRecommendationDetail": "ModifyRecommendationDetailTypeDef",
         "TerminateRecommendationDetail": "TerminateRecommendationDetailTypeDef",
+        "FindingReasonCodes": List[FindingReasonCodeType],
     },
     total=False,
 )
@@ -1433,6 +1462,7 @@ TargetInstanceTypeDef = TypedDict(
         "DefaultTargetInstance": bool,
         "ResourceDetails": "ResourceDetailsTypeDef",
         "ExpectedResourceUtilization": "ResourceUtilizationTypeDef",
+        "PlatformDifferences": List[PlatformDifferenceType],
     },
     total=False,
 )
